@@ -1,17 +1,32 @@
 /* Define to the name of the distribution.  */
 #undef PACKAGE
 
+#undef HAVE_GETTEXT
+#undef HAVE_UNISTD_H
+#undef HAVE_DIRENT_H
+#undef HAVE_FNMATCH_H
+
 /* Define to the version of the distribution.  */
 #undef VERSION
+#undef SCIGRAPHICA_MAJOR_VERSION
+#undef SCIGRAPHICA_MINOR_VERSION
+#undef SCIGRAPHICA_MICRO_VERSION
+#undef SCIGRAPHICA_INTERFACE_AGE
+#undef SCIGRAPHICA_BINARY_AGE
+#undef SCIGRAPHICA_VERSION
+#undef SCIGRAPHICA_CURRENT
+#undef SCIGRAPHICA_REVISION
+#undef SCIGRAPHICA_AGE
+
 
 /* Define to the verbose version info of the distribution.  */
 #undef VERSION_INFO
 
 /* Root of the SciGraphica installation */
-#undef SG_ROOT
+#undef SCIGRAPHICA_ROOT
 
 /* Viewer for Documentation */
-#undef SG_DOCVIEWER
+#undef SCIGRAPHICA_DOCVIEWER
 
 /* Define if your locale.h file contains LC_MESSAGES.  */
 #undef HAVE_LC_MESSAGES
@@ -24,6 +39,7 @@
 
 /* Define as 1 if you have gettext and don't want to use GNU gettext.  */
 #undef HAVE_GETTEXT
+#undef GETTEXT_PACKAGE 
 
 /* Define as 1 if you have the stpcpy function.  */
 #undef HAVE_STPCPY
@@ -42,4 +58,3 @@
 #undef HAVE_DLFCN_H
 #undef HAVE_LIBUTIL
 
-#undef WITH_BONOBO
