@@ -19,8 +19,7 @@
 #ifndef __SG_LOGO_DIALOGS_H__
 #define __SG_LOGO_DIALOGS_H__
 
-void		sg_about_dialog			(GtkWidget *widget,
-						 gpointer data);
+void		sg_about_dialog			(void);
 void		sg_presentation_dialog		(void);
 
 #endif /* __SG_LOGO_DIALOGS_H__ */
