@@ -19,8 +19,7 @@
 #ifndef __SG_PREFERENCES_DIALOG_H__
 #define __SG_PREFERENCES_DIALOG_H__
 
-void general_config_dialog	(GtkWidget *widget,
-				 gpointer data);
+void sg_preferences_dialog();
 
 #endif /* __SG_PREFERENCES_DIALOG_H__ */
 
