@@ -19,15 +19,6 @@
 #ifndef __SG_PROJECT_MENU_H__
 #define __SG_PROJECT_MENU_H__
 
-void		sg_worksheet_popup_show		(GtkIconListItem *item,
-						 GdkEventButton *event);
-void		sg_plot_popup_show		(GtkIconListItem *item,
-						 GdkEventButton *event);
-void		sg_project_build_popups		(void);
-GtkWidget 	*sg_project_build_toolbar	(GtkWidget *top_level);
-GtkWidget	*sg_project_build_menu		(GtkWidget *app);
-
-void		sg_menu_exit			(GtkWidget *widget,
-						 gpointer data);
+GtkWidget*	sg_project_menu_new			(SGapplication *app);
 
 #endif /* __SG_PROJECT_MENU_H__ */
